@@ -6,14 +6,24 @@ use warnings;
 use DynaLoader ();
 
 use vars qw( $VERSION @ISA @EXPORT @EXPORT_OK );
-$VERSION   = "0.32";
+$VERSION   = "0.33";
 @ISA       = qw( DynaLoader Exporter );
-@EXPORT    = qw( DDumper DDsort DPeek DDisplay DDump DHexDump DDual DGrow );
-@EXPORT_OK = qw( triplevar );
+@EXPORT    = qw( DDumper DTidy DDsort DPeek DDisplay DDump DHexDump
+		 DDual DGrow );
+@EXPORT_OK = qw( triplevar :tidy );
 push @EXPORT, "DDump_IO";
 
 bootstrap Data::Peek $VERSION;
 
+our $has_perlio;
+our $has_perltidy;
+
+BEGIN {
+    use Config;
+    $has_perlio   = ($Config{useperlio} || "undef") eq "define";
+    $has_perltidy = eval q{use Perl::Tidy; $Perl::Tidy::VERSION};
+    }
+
 ### ############# DDumper () ##################################################
 
 use Data::Dumper;
@@ -45,7 +55,8 @@ my %sk = (
 	    [ reverse sort                           keys %$r ];
 	    },
     );
-my $_sortkeys = 1;
+my  $_sortkeys = 1;
+our $_perltidy = 0;
 
 sub DDsort
 {
@@ -61,6 +72,11 @@ sub import
     foreach my $p (@exp) {
 	exists $sk{$p} and DDsort ($p), next;
 
+	if ($p eq ":tidy") {
+	    $_perltidy = $has_perltidy;
+	    next;
+	    }
+
 	push @etl, $p;
 	}
     __PACKAGE__->export_to_level (1, @etl);
@@ -68,6 +84,8 @@ sub import
 
 sub DDumper
 {
+    $_perltidy and goto \&DTidy;
+
     local $Data::Dumper::Sortkeys  = $_sortkeys;
     local $Data::Dumper::Indent    = 1;
     local $Data::Dumper::Quotekeys = 0;
@@ -76,7 +94,7 @@ sub DDumper
     local $Data::Dumper::Useqq     = 0;	# I want unicode visible
 
     my $s = Data::Dumper::Dumper @_;
-    $s =~ s/^(\s*)(.*?)\s*=>/sprintf "%s%-16s =>", $1, $2/gme;	# Align =>
+    $s =~ s/^(\s*)(.*?)\s*=>/sprintf "%s%-16s =>", $1, $2/gme;  # Align =>
     $s =~ s/\bbless\s*\(\s*/bless (/gm and $s =~ s/\s+\)([;,])$/)$1/gm;
     $s =~ s/^(?= *[]}](?:[;,]|$))/  /gm;
     $s =~ s/^(\s*[{[]) *\n *(?=\S)(?![{[])/$1   /gm;
@@ -86,15 +104,27 @@ sub DDumper
     return $s;
     } # DDumper
 
+sub DTidy
+{
+    $has_perltidy or goto \&DDumper;
+
+    local $Data::Dumper::Sortkeys  = $_sortkeys;
+    local $Data::Dumper::Indent    = 1;
+    local $Data::Dumper::Quotekeys = 1;
+    local $Data::Dumper::Deparse   = 1;
+    local $Data::Dumper::Terse     = 1;
+    local $Data::Dumper::Useqq     = 0;
+
+    my $s = Data::Dumper::Dumper @_;
+    Perl::Tidy::perltidy (source => \$s, destination => \my $t);
+    $s = $t;
+
+    defined wantarray or warn $s;
+    return $s;
+    } # DTidy
+
 ### ############# DDump () ####################################################
 
-our $has_perlio;
-
-BEGIN {
-    use Config;
-    $has_perlio = ($Config{useperlio} || "undef") eq "define";
-    }
-
 sub _DDump_ref
 {
     my (undef, $down) = (@_, 0);
@@ -206,6 +236,7 @@ Data::Peek - A collection of low-level debug facilities
  use Data::Peek;
 
  print DDumper \%hash;    # Same syntax as Data::Dumper
+ DTidy { ref => $ref };
 
  print DPeek \$var;
  my ($pv, $iv, $nv, $rv, $magic) = DDual ($var [, 1]);
@@ -225,9 +256,12 @@ Data::Peek - A collection of low-level debug facilities
  close $fh;
  print $dump;
 
- use Data::Peek qw( DGrow triplevar );
+ # Imports
+ use Data::Peek qw( :tidy VNR DGrow triplevar );
  my $x = ""; DGrow ($x, 10000);
  my $tv = triplevar ("\N{GREEK SMALL LETTER PI}", 3, "3.1415");
+ DDsort ("R");
+ DDumper [ $x ]; # use of :tidy make DDumper behave as DTidy
 
 =head1 DESCRIPTION
 
@@ -246,7 +280,9 @@ everything set as I like it.
     $Data::Dumper::Sortkeys = 1;
     $Data::Dumper::Indent   = 1;
 
-And the result is further beautified to meet my needs:
+If C<Data::Peek> is C<use>d with import argument C<:tidy>, the result is
+formatted according to L<Perl::Tidy>, see L<DTidy> below, otherwise the
+result is further beautified to meet my needs:
 
   * quotation of hash keys has been removed (with the disadvantage
     that the output might not be parseable again).
@@ -257,7 +293,8 @@ In void context, C<DDumper ()> warn ()'s.
 
 Example
 
-  print DDumper { ape => 1, foo => "egg", bar => [ 2, "baz", undef ]};
+  $ perl -MDP \
+    -e'DDumper { ape => 1, foo => "egg", bar => [ 2, "baz", undef ]};'
 
   {   ape              => 1,
       bar              => [
@@ -268,6 +305,26 @@ Example
       foo              => 'egg'
       };
 
+=head2 DTidy ($var, ...)
+
+C<DTidy> is an alternative to C<DDumper>, where the output of C<DDumper>
+is formatted using C<Perl::Tidy> (if available) according to your
+C<.perltidyrc> instead of the default behavior, maybe somewhat like (YMMV):
+
+  $ perl -MDP=:tidy \
+    -we'DDumper { ape => 1, foo => "egg", bar => [ 2, "baz", undef ]};'
+  {   'ape' => 1,
+      'bar' => [2, 'baz', undef],
+      'foo' => 'egg'
+      }
+
+If C<Data::Peek> is C<use>d with import argument C<:tidy>, this is the
+default output method for C<DDumper>.
+
+If L<Perl::Tidy> is not available, C<DTidy> will fallback to C<DDumper>.
+
+This idea was shamelessly copied from John McNamara's L<Data::Dumper::Perltidy>.
+
 =head2 DDsort ( 0 | 1 | R | V | VR | VN | VNR )
 
 Set the hash sort algorithm for DDumper. The default is to sort by key value.
@@ -282,13 +339,15 @@ Set the hash sort algorithm for DDumper. The default is to sort by key value.
 
 These can also be passed to import:
 
-  $ perl -MDP=VNR -we'DDumper { foo => 1, bar => 2, zap => 3, gum => 13 }'
+  $ perl -MDP=VNR \
+    -we'DDumper { foo => 1, bar => 2, zap => 3, gum => 13 }'
   {   gum              => 13,
       zap              => 3,
       bar              => 2,
       foo              => 1
       };
-  $ perl -MDP=V   -we'DDumper { foo => 1, bar => 2, zap => 3, gum => 13 }'
+  $ perl -MDP=V \
+    -we'DDumper { foo => 1, bar => 2, zap => 3, gum => 13 }'
   {   foo              => 1,
       gum              => 13,
       bar              => 2,
@@ -370,7 +429,7 @@ In void context, DDual does the equivalent of
       "  RV: ", DPeek ($d[3]), "\n";
     }
   
-=head2 my $LEN = DGrow ($pv, $size)
+=head2 my $len = DGrow ($pv, $size)
 
 Fastest way to preallocate space for a PV scalar. Returns the allocated
 length. If $size is smaller than the already allocated space, it will
@@ -388,7 +447,7 @@ not shrink.
  grow 1622943/s 2512%  967%    --
 
 
-=head2 triplevar ($pv, $iv, $nv)
+=head2 my $tp = triplevar ($pv, $iv, $nv)
 
 When making C<DDual ()> I wondered if it were possible to create triple-val
 scalar variables. L<Scalar::Util> already gives us C<dualvar ()>, that creates
@@ -607,7 +666,7 @@ proven to be a big help.
 =head1 SEE ALSO
 
 L<Devel::Peek>, L<Data::Dumper>, L<Data::Dump>, L<Devel::Dumpvar>,
-L<Data::Dump::Streamer>
+L<Data::Dump::Streamer>, L<Data::Dumper::Perltidy>, L<Perl::Tidy>.
 
 =head1 AUTHOR
 
@@ -615,7 +674,7 @@ H.Merijn Brand <h.m.brand@xs4all.nl>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008-2010 H.Merijn Brand
+Copyright (C) 2008-2011 H.Merijn Brand
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
